@@ -1,6 +1,6 @@
 #
 # The MIT License (MIT)
-# Copyright (c) 2021 M.O.S.S. Computer Grafik Systeme GmbH
+# Copyright (c) 2022 M.O.S.S. Computer Grafik Systeme GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the "Software"),
@@ -26,9 +26,11 @@ import mimetypes
 import os
 import re
 from typing import List, Optional
-from moss.ems.utilities import PaginationQuery
+
 from requests import Response
 
+from moss.ems.utilities import PaginationQuery
+
 logger = logging.getLogger(__file__)
 
 
@@ -73,8 +75,8 @@ class EmsLayer(object):
             where: a SQL-like string
             geometry: am Esri Envelope used to filter the query
             variants: a list of variant IDs to query
-            **kwargs: additional a keyworded, variable-length argument list, please refer
-            to ems documentation
+            **kwargs: additional a keyworded, variable-length argument list
+            please refer to ems documentation
 
         Returns:
             a pagination query object
@@ -217,10 +219,7 @@ class EmsLayer(object):
                 if attribute in exclude_fields:
                     feature["attributes"].pop(attribute, None)
 
-        post_data = {
-            "f": "json",
-            "features": json.dumps(features),
-        }
+        post_data = {"f": "json", "features": json.dumps(features)}
         # Add the variant parameter if provided
         if variant_id is not None:
             logger.debug("Using variant: variant_id is %s ", variant_id)
@@ -605,15 +604,14 @@ class EmsLayer(object):
         return True
 
     def download_attachment(self, feature_id, attachment_id, output_path=None):
-        # type: (int, int, Optional[str]) -> bool
+        # type: (int, int, Optional[str]) -> Optional[bool]
         """
         Download the specified attachment
 
         Args:
             feature_id (int): The ID of the feature owning the attachment
             attachment_id (int): The attachments ID
-            output_path (str): Output directory where the attachment will be
-            saved
+            output_path (str): Output directory where the attachment will be saved
         Returns:
             bool: The result of the download attachment
         """
@@ -638,33 +636,34 @@ class EmsLayer(object):
 
         response = self._session.get(url)  # type: Response
         content_type = response.headers.get("Content-Type")  # type: Optional[str]
-        if "application/json" not in content_type:
-            logger.info("Headers {0}".format(response.headers))
+        if content_type is not None:
+            if "application/json" not in content_type:
+                logger.info("Headers {0}".format(response.headers))
 
-            content_disposition = response.headers.get("Content-Disposition")
-            if content_disposition:
-                filename = re.findall("filename=(.+)", content_disposition)[0]
+                content_disposition = response.headers.get("Content-Disposition")
+                if content_disposition:
+                    filename = re.findall("filename=(.+)", content_disposition)[0]
+                else:
+                    filename = "no_name"
+                logger.info("Saving attachment to {0}".format(filename))
+
+                if output_path:
+                    if not os.path.exists(output_path):
+                        logger.error("The path {0} does not exist".format(output_path))
+                        return False
+
+                    attachment_path = os.path.join(output_path, filename)
+
+                else:
+                    attachment_path = filename
+
+                logger.debug("Saving attachment to {0}".format(attachment_path))
+                with open(attachment_path, "wb") as output_file:
+                    output_file.write(response.content)
+                return True
             else:
-                filename = "no_name"
-            logger.info("Saving attachment to {0}".format(filename))
-
-            if output_path:
-                if not os.path.exists(output_path):
-                    logger.error("The path {0} does not exist".format(output_path))
-                    return False
-
-                attachment_path = os.path.join(output_path, filename)
-
-            else:
-                attachment_path = filename
-
-            logger.debug("Saving attachment to {0}".format(attachment_path))
-            with open(attachment_path, "wb") as output_file:
-                output_file.write(response.content)
-            return True
-        else:
-            logger.error("The attachment url {0} does not exist".format(url))
-            return False
+                logger.error("The attachment url {0} does not exist".format(url))
+                return False
 
     def __repr__(self):
         return self.name
