@@ -1,6 +1,6 @@
 #
 # The MIT License (MIT)
-# Copyright (c) 2021 M.O.S.S. Computer Grafik Systeme GmbH
+# Copyright (c) 2022 M.O.S.S. Computer Grafik Systeme GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the "Software"),
@@ -23,7 +23,7 @@
 import json
 import logging
 
-from anytree import Node, find_by_attr, PreOrderIter, RenderTree
+from anytree import Node, PreOrderIter, RenderTree, find_by_attr
 from anytree.exporter import DictExporter
 
 from .emscatalog import EmsCatalog
@@ -386,7 +386,7 @@ class EmsProject:
 
                 # We sort all the variants. This help to build the variant because
                 # the variant id will be always bigger
-                sorted_variant = sorted(variant_list, key=lambda k: k["ID"])  # type: ignore
+                sorted_variant = sorted(variant_list, key=lambda k: k["ID"])
                 complete_list.extend(sorted_variant)
 
         # Crete the tree, this is the first node
@@ -436,7 +436,12 @@ class EmsProject:
         """
 
         variant_master_objectclass = next(
-            (item for item in self.objectclasses if item.objectClassType == "VNTMASTER"), None  # type: ignore
+            (
+                item
+                for item in self.objectclasses
+                if item.objectClassType == "VNTMASTER"
+            ),
+            None,
         )
 
         return variant_master_objectclass is not None
