@@ -1,6 +1,6 @@
 #
 # The MIT License (MIT)
-# Copyright (c) 2021 M.O.S.S. Computer Grafik Systeme GmbH
+# Copyright (c) 2022 M.O.S.S. Computer Grafik Systeme GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the "Software"),
@@ -53,27 +53,30 @@ class Service(object):
     """
     A Class used to represent an EMS Service.
 
-    Examples
-    --------
-
     To access a WEGA-EMS Service without authentication:
 
+    Example:
         >>> my_service = Service("http://localhost:8080/wega-ems/")
         >>> my_service.projects
+        ["project1", "project2"]
 
     If the service uses authentication, username and password can be provided
     as additional parameters:
 
+    Example:
         >>> my_service = Service("http://localhost:8080/wega-ems/",
                 username="Test",
                 password="Test")
         >>> my_service.projects
+        ["project1", "project2"]
 
     If working wih token, you can easily ignore the username and password:
 
+    Example:
         >>> my_service = Service("http://localhost:8080/wega-ems/",
                                 token="aabbcc")
         >>> my_service.projects
+        ["project1", "project2"]
 
     Emspy uses requests Session so the session will remain active until close()
     is called.This will perform also a logout on Tomcat.
@@ -81,12 +84,15 @@ class Service(object):
     Args:
 
         url (str):      The url to the WEGA-EMS instance service.
-        username (`str`, optional): The username used for authentication.
-        password (`str`, optional): The password used for authentication.
-        token (`str`, optional): The token used for authentication
+        username (str, optional): The username used for authentication.
+        password (str, optional): The password used for authentication.
+        token (str, optional): The token used for authentication
     """
 
     def __init__(self, base_url, username=None, password=None, token=None):
+        # type: (str, str, str, str) -> None
+        if not base_url.endswith("/"):
+            base_url = base_url + "/"
         self.base_url = base_url
         self.username = username
         self.password = password
@@ -127,7 +133,7 @@ class Service(object):
 
         url = "login.xhtml"
 
-        logger.debug("Logging user using the address %s", url)
+        logger.info("Logging user using the address %s", url)
         payload = {"username": self.username, "password": self.password}
         self.session.post(url, data=payload)
 
@@ -169,6 +175,10 @@ class Service(object):
         Check if the url is correct
         """
         url = "/".join([self.base_url, "rest"])
+        logger.info("Url %s", url)
+
+        if "jsessionid" in url:
+            url = url.split(";")[0]
         try:
             response = requests.get(url)
         except (ValueError, requests.exceptions.ConnectionError) as exception:
@@ -177,7 +187,7 @@ class Service(object):
             )
             return False
         else:
-            return response.status_code == 200
+            return response.status_code == 200 or response.status_code == 400
 
     def _service_is_secured(self):
         """
@@ -203,11 +213,10 @@ class Service(object):
         """
         List of all projects with some meta data.
 
-        Example
-        --------
+        Examples:
 
-        >>> my_service = Service("http://localhost:8080/wega-ems/")
-        >>> my_service.info
+            >>> my_service = Service("http://localhost:8080/wega-ems/")
+            >>> my_service.info
 
         Returns:
             list: A list of projects and meta data for the current service
@@ -224,12 +233,6 @@ class Service(object):
         """
         Return the base configuration of an administration client.
 
-        Example
-        --------
-
-        >>> my_service = Service("http://localhost:8080/wega-ems/")
-        >>> my_service.configuration
-
         Returns:
             a configuration dictionary containing a
             success property and version
@@ -247,14 +250,14 @@ class Service(object):
         """
         The list of all the projects in the current Service.
 
-        Example
-        --------
+        Example:
 
-        >>> my_service = Service("http://localhost:8080/wega-ems/")
-        >>> my_service.projects
+            >>> my_service = Service("http://localhost:8080/wega-ems/")
+            >>> my_service.projects
+            ['project1', 'project2']
 
         Returns:
-            :obj:`list` of :obj:`EmsProject`
+           list: A list of `EmsProject`
         """
         url = "/".join(["rest", "projects"])
         parameters = {"f": "json"}
@@ -276,14 +279,12 @@ class Service(object):
             description (str, optional): The project description.
             If not provided it will be an empty string.
 
-        Example
-        --------
-
-        >>> my_service = Service("http://localhost:8080/wega-ems/")
-        >>> my_service.add_project("PROJECT", "Beschreibung")
+        Example:
+            >>> my_service = Service("http://localhost:8080/wega-ems/")
+            >>> my_service.add_project("PROJECT", "Beschreibung")
 
         Returns
-            The :obj:`EmsProject` instance of the added project
+            The `EmsProject` instance of the added project
             or None in case of error
         """
         logger.debug("Trying to add the project '" + project_name + "'.")
@@ -319,23 +320,19 @@ class Service(object):
 
     def delete_project(self, project_name):
         """
-        Deletes the project with the provided name.
+        Deletes the provided project. This operation can not be undone.
 
         Args:
-            project_name: Project name
+            project_name (str): Project name
 
-        Example
-        --------
+        Examples:
 
-        >>> my_service = Service("http://localhost:8080/wega-ems/")
-        >>> my_service.delete_project("PROJECT")
+            >>> my_service = Service("http://localhost:8080/wega-ems/")
+            >>> my_service.delete_project("PROJECT")
 
-        Returns
-            True: project deleted successfully.
-            False: an error occurred.
+        Returns:
+            bool: `True` or `False` if the project deleted successfully.
 
-        .. warning::
-            After this operation the project is physically deleted
         """
         projects = self.projects
 
@@ -438,7 +435,10 @@ class Service(object):
         return response_dict
 
     def import_project(
-        self, project_definition, project_name, password=None,
+        self,
+        project_definition,
+        project_name,
+        password=None,
     ):
         """
         Import a project using the provided dict
@@ -491,9 +491,7 @@ class Service(object):
             return False
 
     def _ems_request(self, url, parameters, method="GET"):
-        """ Return a json response from a session
-
-        """
+        """Return a json response from a session"""
         logger.debug("New request to %s parameters %s", url, parameters)
 
         if method == "POST":
@@ -508,7 +506,7 @@ class Service(object):
 
         if response.status_code != 200:  # pragma: no cover
             logger.error(
-                ("Response is %s. Url: %s Parameters:" "%s Status code: %s"),
+                "Response is %s. Url: %s Parameters:%s Status code: %s",
                 response.status_code,
                 url,
                 parameters,
@@ -521,7 +519,7 @@ class Service(object):
             json_response = response.json()
         except ValueError as exception:  # pragma: no cover
             logger.exception(
-                ("Response is not json. You are probably" "on the login website:%s"),
+                "Response is not json. You are probablyon the login website:%s",
                 exception,
             )
         else:
